@@ -903,7 +903,8 @@ public class EncoderConfiguration {
 			code = "Linear - inertial machine";
 			text = Catalog.GetString("Linear encoder on inertia machine.") + "\n" + 
 				Catalog.GetString("Configuration NOT Recommended! Please use a rotary encoder.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*";
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" + 
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 			
 			has_d = true;
 			has_inertia = true;
@@ -1005,7 +1006,8 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionSideInertial;
 			code = "Rotary friction - inertial machine side";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine side.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*";
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" +
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
 			has_D = true;
@@ -1017,7 +1019,8 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionAxisInertial;
 			code = "Rotary friction axis - inertial machine axis";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine axis.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*";
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" + 
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
 			has_inertia = true;
@@ -1044,7 +1047,8 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderAxisInertial;
 			code = "Rotary axis - inertial machine";
 			text = Catalog.GetString("Rotary axis encoder on inertial machine.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*";
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" +
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
 			has_inertia = true;
