@@ -100,6 +100,7 @@ public class GenericWindow
 	//and we want to ensure next window will be created at needed size
 	public bool DestroyOnAccept;
 	public int TreeviewSelectedUniqueID;
+	private int commentColumn;
 
 	public GenericWindow ()
 	{
@@ -424,9 +425,12 @@ public class GenericWindow
 		textview.Buffer = tb;
 	}
 	
+	bool activateRowAcceptsWindow;
 	//data is an ArrayList of strings[], each string [] is a row, each of its strings is a column
 	public void SetTreeview(string [] columnsString, bool addCheckbox, 
-			ArrayList data, ArrayList myNonSensitiveRows, Constants.ContextMenu contextMenu) 
+			ArrayList data, ArrayList myNonSensitiveRows, Constants.ContextMenu contextMenu,
+			bool activateRowAcceptsWindow	//this param makes button_accept the window if 'enter' on a row or double click
+			) 
 	{
 		//adjust window to be bigger
 		generic_window.Resizable = true;
@@ -447,6 +451,7 @@ Log.WriteLine("aaaaaaaaaaaaaaaa1");
 Log.WriteLine("aaaaaaaaaaaaaaaa2");	
 
 		genericWinContextMenu = contextMenu;
+		this.activateRowAcceptsWindow = activateRowAcceptsWindow;
 
 		treeview.CursorChanged += on_treeview_cursor_changed; 
 		if(contextMenu == Constants.ContextMenu.EDITDELETE) {
@@ -603,6 +608,21 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 			}
 		}
 	}
+	
+	void on_row_double_clicked (object o, Gtk.RowActivatedArgs args)
+	{
+		if(activateRowAcceptsWindow) {
+			TreeView tv = (TreeView) o;
+			TreeModel model;
+			TreeIter iter;
+
+			if (tv.Selection.GetSelected (out model, out iter)) {
+				//activate on_button_accept_clicked()
+				button_accept.Activate();
+			}
+		}
+	}
+	
 
 	private void on_treeview_button_release_event (object o, ButtonReleaseEventArgs args) {
 		//TreeviewSelectedUniqueID = -1;
@@ -648,7 +668,7 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 		TreeModel model;
 		TreeIter iter = new TreeIter();
 		treeview.Selection.GetSelected (out model, out iter);
-		entry_edit_row.Text = (string) model.GetValue (iter, 8);
+		entry_edit_row.Text = (string) model.GetValue (iter, commentColumn);
 
 		button_row_edit.Click();
 	}
@@ -661,7 +681,7 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 		TreeModel model;
 		TreeIter iter = new TreeIter();
 		treeview.Selection.GetSelected (out model, out iter);
-		store.SetValue (iter, 8, entry_edit_row.Text);
+		store.SetValue (iter, commentColumn, entry_edit_row.Text);
 	}
 	
 
@@ -670,13 +690,16 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 	}
 
 	private void on_delete_selected_clicked (object o, EventArgs args) {
-		//remove selected row from treeview
-		store = UtilGtk.RemoveRow(treeview, store);
-
 		//activate button to manage on gui/encoder.cs in order to delete from SQL
 		button_row_delete.Click();
 	}
 
+	//if confirmed deletion, this will be called
+	public void Delete_row_accepted() {
+		//remove selected row from treeview
+		store = UtilGtk.RemoveRow(treeview, store);
+	}
+
 	
 	public void SetButtonAcceptLabel(string str) {
 		button_accept.Label=str;
@@ -737,6 +760,10 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 		set { hbox_combo_button = value; }
 		get { return hbox_combo_button; }
 	}
+	
+	public int CommentColumn {
+		set { commentColumn = value; }
+	}
 		
 	public Button Button_row_delete {
 		set { button_row_delete = value; }
