@@ -1061,11 +1061,30 @@ partial class ChronoJumpWindow
 	private JumpType previousJumpType; //used on More to turnback if cancel or delete event is pressed
 	private JumpType previousJumpRjType; //used on More to turnback if cancel or delete event is pressed
 	
+	
+	//creates and if is not predefined, checks database to gather all the data
+	//simple == true  for normal jumps, and false for reactive
+	private JumpType createJumpType(string name, bool simple) {
+		JumpType t = new JumpType(name);
+		
+		if(! t.IsPredefined) {
+			if(simple) {
+				t = SqliteJumpType.SelectAndReturnJumpType(name, false);
+				t.ImageFileName = SqliteEvent.GraphLinkSelectFileName(Constants.JumpTable, name);
+			} else {
+				t = SqliteJumpType.SelectAndReturnJumpRjType(name, false);
+				t.ImageFileName = SqliteEvent.GraphLinkSelectFileName(Constants.JumpRjTable, name);
+			}
+		}
+		return t;
+	}
+	
+	
 	private void on_extra_window_jumps_test_changed(object o, EventArgs args)
 	{
 		string jumpEnglishName = Util.FindOnArray(':',2,1, UtilGtk.ComboGetActive(combo_select_jumps), selectJumpsString);
-		currentJumpType = new JumpType(jumpEnglishName);
-		
+		currentJumpType = createJumpType(jumpEnglishName, true);
+	
 		extra_window_jumps_initialize(currentJumpType);
 	}
 	
@@ -1082,8 +1101,8 @@ partial class ChronoJumpWindow
 	private void on_extra_window_jumps_rj_test_changed(object o, EventArgs args)
 	{
 		string jumpEnglishName = Util.FindOnArray(':',2,1, UtilGtk.ComboGetActive(combo_select_jumps_rj), selectJumpsRjString);
-		currentJumpRjType = new JumpType(jumpEnglishName);
-		
+		currentJumpRjType = createJumpType(jumpEnglishName, false);
+
 		extra_window_jumps_rj_initialize(currentJumpRjType);
 	}
 
@@ -1110,13 +1129,11 @@ partial class ChronoJumpWindow
 		} else 
 			extra_window_showWeightData(myJumpType, false);	
 
-		if(myJumpType.StartIn || myJumpType.Name == Constants.TakeOffName || 
-				myJumpType.Name == Constants.TakeOffWeightName) 
-			extra_window_showFallData(myJumpType, false);	
-		else {
+		if(myJumpType.HasFall) {
 			hasOptions = true;
 			extra_window_showFallData(myJumpType, true);
-		}
+		} else
+			extra_window_showFallData(myJumpType, false);	
 		
 		if(myJumpType.Name == "DJa" || myJumpType.Name == "DJna") { 
 			//on DJa and DJna (coming from More jumps) need to show technique data but not change
@@ -1192,13 +1209,11 @@ partial class ChronoJumpWindow
 		} else 
 			extra_window_showWeightData(myJumpType, false);	
 
-		if(myJumpType.StartIn || myJumpType.Name == Constants.TakeOffName || 
-				myJumpType.Name == Constants.TakeOffWeightName)
-			extra_window_showFallData(myJumpType, false);	
-		else {
+		if(myJumpType.HasFall || myJumpType.Name == Constants.RunAnalysisName) {
 			extra_window_showFallData(myJumpType, true);	
 			hasOptions = true;
-		}
+		} else
+			extra_window_showFallData(myJumpType, false);
 		
 		extra_window_jumps_rj_spinbutton_weight.Value = extra_window_jumps_rj_weight;
 		extra_window_jumps_rj_spinbutton_fall.Value = extra_window_jumps_rj_fall;
@@ -1246,7 +1261,7 @@ partial class ChronoJumpWindow
 	{
 		jumpsMoreWin.Button_accept.Clicked -= new EventHandler(on_more_jumps_accepted);
 		
-		currentJumpType = new JumpType(jumpsMoreWin.SelectedEventName);
+		currentJumpType = createJumpType(jumpsMoreWin.SelectedEventName, true);
 
 		extra_window_jumps_initialize(currentJumpType);
 		
@@ -1260,7 +1275,7 @@ partial class ChronoJumpWindow
 	{
 		jumpsRjMoreWin.Button_accept.Clicked -= new EventHandler(on_more_jumps_rj_accepted);
 
-		currentJumpRjType = new JumpType(jumpsRjMoreWin.SelectedEventName);
+		currentJumpRjType = createJumpType(jumpsRjMoreWin.SelectedEventName, false);
 		
 		extra_window_jumps_rj_initialize(currentJumpRjType);
 	
