@@ -36,7 +36,6 @@ public class PreferencesWindow {
 
 	[Widget] Gtk.Label label_database;
 	[Widget] Gtk.Label label_database_temp;
-	[Widget] Gtk.Label label_logs;
 	
 	[Widget] Gtk.Button button_db_folder_open;
 
@@ -121,7 +120,6 @@ public class PreferencesWindow {
 		//database and log files stuff
 		label_database.Text = Util.GetDatabaseDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
 		label_database_temp.Text = Util.GetDatabaseTempDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
-		//label_logs.Text = Log.GetDir();
 	}
 	
 	static public PreferencesWindow Show (int digitsNumber, bool showHeight, bool showPower,  
@@ -337,7 +335,7 @@ public class PreferencesWindow {
 	void on_preferences_delete_event (object o, DeleteEventArgs args)
 	{
 		//do not hide/exit if copyiing
-		if (thread.IsAlive)
+		if (thread != null && thread.IsAlive)
 			args.RetVal = true;
 		else {
 			PreferencesWindowBox.preferences.Hide();
@@ -364,6 +362,32 @@ public class PreferencesWindow {
 	void on_check_backup_encoder_tests_clicked(object o, EventArgs args) {
 		check_backup_multimedia.Active = check_backup_encoder_tests.Active;
 	}	
+	
+	
+	void on_button_logs_folder_open_clicked (object o, EventArgs args)
+	{
+		string dir = Util.GetLogsDir();
+		Log.WriteLine(dir);
+		
+		if( ! new System.IO.DirectoryInfo(dir).Exists) {
+			try {
+				Directory.CreateDirectory (dir);
+			} catch {
+				new DialogMessage(Constants.MessageTypes.WARNING, 
+						Catalog.GetString("Cannot create directory.") + "\n\n" + dir);
+				return;
+			}
+		}
+		
+		try {
+			System.Diagnostics.Process.Start(dir); 
+		}
+		catch {
+			new DialogMessage(Constants.MessageTypes.WARNING, 
+					Constants.DirectoryCannotOpen + "\n\n" + dir);
+		}
+	}
+
 
 
 	string fileDB;
