@@ -81,6 +81,7 @@ public partial class ChronoJumpWindow {
 	[Widget] Gtk.Image image_stats_win_graph;
 	[Widget] Gtk.Image image_stats_win_graph1;
 	[Widget] Gtk.Image image_stats_win_graph2;
+	[Widget] Gtk.Image image_stats_win_graph3;
 	[Widget] Gtk.Image image_stats_win_report_open;
 	[Widget] Gtk.Image image_results;
 		
@@ -188,7 +189,7 @@ public partial class ChronoJumpWindow {
 		Catalog.GetString("No indexes"), 
 		Constants.FvIndexFormula,
 		Constants.IeIndexFormula, 
-		Constants.IubIndexFormula,
+		Constants.ArmsUseIndexFormula,
 		Constants.IRnaIndexFormula,
 		Constants.IRaIndexFormula,
 		Catalog.GetString(Constants.SubtractionBetweenTests),
@@ -292,6 +293,7 @@ public partial class ChronoJumpWindow {
 		image_stats_win_graph.Pixbuf = pixbuf;
 		image_stats_win_graph1.Pixbuf = pixbuf;
 		image_stats_win_graph2.Pixbuf = pixbuf;
+		image_stats_win_graph3.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "report_view.png");
 		image_stats_win_report_open.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "spreadsheet.png");
@@ -655,7 +657,7 @@ public partial class ChronoJumpWindow {
 				UtilGtk.ComboUpdate(combo_stats_stat_apply_to, "CMJ, SJ");
 				combo_stats_stat_apply_to.Active = 0;
 				combo_stats_stat_apply_to.Sensitive = false;
-			} else if (UtilGtk.ComboGetActive(combo_stats_stat_subtype) == Constants.IubIndexFormula) {
+			} else if (UtilGtk.ComboGetActive(combo_stats_stat_subtype) == Constants.ArmsUseIndexFormula) {
 				UtilGtk.ComboUpdate(combo_stats_stat_apply_to, "ABK, CMJ");
 				combo_stats_stat_apply_to.Active = 0;
 				combo_stats_stat_apply_to.Sensitive = false;
