@@ -21,6 +21,7 @@
 using System;
 using System.Data;
 using Gtk;
+using System.Collections; //ArrayList
 
 //this file has classes to allow to pass gui objectes easily
 public class ExecutingGraphData
@@ -303,3 +304,34 @@ public class UpdateProgressBar {
 	~UpdateProgressBar() {}
 }
 
+
+/*
+ * TrCombo (Translatable Combo)
+ * use this with an arraylist instead of strings [], and the Util.FindOnArray
+ * see implementation on ExecuteAutoWindow
+ */
+
+public class TrCombo {
+	public int id; 		//uniqueID
+	public string eName;	//englishName
+	public string trName;	//translatedName
+	public ArrayList options;
+
+	/*
+	public TrCombo() {
+	}
+	*/
+
+	public TrCombo(int id, string eName, string trName, ArrayList options) {
+		this.id = id;
+		this.eName = eName;
+		this.trName = trName;
+		this.options = options;
+	}
+
+	public override string ToString() {
+		return id + ":" + eName + ":" + trName + ":" + Util.ArrayListToSingleString(options, ":"); 
+	}
+
+	~TrCombo() {}
+}
