@@ -56,7 +56,8 @@ class SqliteEncoder : Sqlite
 			"status TEXT, " +	//"active", "inactive"
 			"videoURL TEXT, " +	//URL of video of signals
 			"encoderConfiguration TEXT, " +	//text separated by ':'
-		       	"future1 TEXT, " + 
+		       	"future1 TEXT, " +	//Since 1.4.4 (DB 1.06) this stores last meanPower detected on a curve 
+						//(as string with '.' because future1 was created as TEXT)
 		       	"future2 TEXT, " + 
 		       	"future3 TEXT )";
 		dbcmd.ExecuteNonQuery();
@@ -86,7 +87,7 @@ class SqliteEncoder : Sqlite
 			es.url + "', " + es.time + ", " + es.minHeight + ", '" + es.description + 
 			"', '" + es.status + "', '" + es.videoURL + "', '" + 
 			es.encoderConfiguration.ToString(":",true) + "', '" + 
-			es.future1 + "', '" + es.future2 + "', '" + es.future3 + "')";
+			Util.ConvertToPoint(es.future1) + "', '" + es.future2 + "', '" + es.future3 + "')";
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -126,7 +127,7 @@ class SqliteEncoder : Sqlite
 				"', status = '" + es.status + 
 				"', videoURL = '" + es.videoURL + 
 				"', encoderConfiguration = '" + es.encoderConfiguration.ToString(":",true) + 
-				"', future1 = '" + es.future1 + 
+				"', future1 = '" + Util.ConvertToPoint(es.future1) + 
 				"', future2 = '" + es.future2 + 
 				"', future3 = '" + es.future3 + 
 				"' WHERE uniqueID == " + es.uniqueID ;
@@ -139,14 +140,20 @@ class SqliteEncoder : Sqlite
 	}
 	
 	//pass uniqueID value and then will return one record. do like this:
-	//EncoderSQL eSQL = (EncoderSQL) SqliteEncoder.Select(false, myUniqueID, 0, 0, "")[0];
+	//EncoderSQL eSQL = (EncoderSQL) SqliteEncoder.Select(false, myUniqueID, 0, 0, "", false, true)[0];
+	//don't care for the 0, 0 , because selection will be based on the myUniqueID and only one row will be returned
 	//or
 	//pass uniqueID==-1 and personID, sessionID, signalOrCurve values, and will return some records
 	//personID can be -1 to get all on that session
 	//sessionID can be -1 to get all sessions
 	//signalOrCurve can be "all"
+	
+	//orderIDascendent is good for all the situations except when we want to convert from 1.05 to 1.06
+	//in that conversion, we want first the last ones, and later the previous
+	//	(to delete them if they are old copies)
 	public static ArrayList Select (bool dbconOpened, 
-			int uniqueID, int personID, int sessionID, string signalOrCurve, bool onlyActive)
+			int uniqueID, int personID, int sessionID, string signalOrCurve, 
+			bool onlyActive, bool orderIDascendent)
 	{
 		if(! dbconOpened)
 			dbcon.Open();
@@ -177,6 +184,10 @@ class SqliteEncoder : Sqlite
 		if(onlyActive)
 			onlyActiveString = " AND " + Constants.EncoderTable + ".status = 'active' ";
 
+		string orderIDstr = "";
+		if(! orderIDascendent)
+			orderIDstr = " DESC";
+
 		dbcmd.CommandText = "SELECT " + 
 			Constants.EncoderTable + ".*, " + Constants.EncoderExerciseTable + ".name FROM " + 
 			Constants.EncoderTable  + ", " + Constants.EncoderExerciseTable  + 
@@ -184,7 +195,8 @@ class SqliteEncoder : Sqlite
 			andString + Constants.EncoderTable + ".exerciseID = " + 
 				Constants.EncoderExerciseTable + ".uniqueID " +
 				onlyActiveString +
-			" ORDER BY substr(filename,-23,19)"; //this contains the date of capture signal
+			" ORDER BY substr(filename,-23,19), " + //'filename,-23,19' has the date of capture signal
+			"uniqueID " + orderIDstr; 
 
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		
@@ -201,7 +213,7 @@ class SqliteEncoder : Sqlite
 				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
 			econf.FromSQL(strFull);
 			
-			Log.WriteLine(econf.ToString(":", true));
+			//Log.WriteLine(econf.ToString(":", true));
 			es = new EncoderSQL (
 					reader[0].ToString(),			//uniqueID
 					Convert.ToInt32(reader[1].ToString()),	//personID	
@@ -219,7 +231,7 @@ class SqliteEncoder : Sqlite
 					reader[13].ToString(),			//status
 					reader[14].ToString(),			//videoURL
 					econf,					//encoderConfiguration
-					reader[16].ToString(),			//future1
+					Util.ChangeDecimalSeparator(reader[16].ToString()),	//future1 (meanPower on curves)
 					reader[17].ToString(),			//future2
 					reader[18].ToString(),			//future3
 					reader[19].ToString()			//EncoderExercise.name
@@ -294,6 +306,109 @@ class SqliteEncoder : Sqlite
 		return array;
 	}
 
+	/*
+	 * EncoderSignalCurve
+	 */
+	
+	protected internal static void createTableEncoderSignalCurve()
+	{
+		dbcmd.CommandText = 
+			"CREATE TABLE " + Constants.EncoderSignalCurveTable + " ( " +
+			"uniqueID INTEGER PRIMARY KEY, " +
+			"signalID INT, " +
+			"curveID INT, " +
+			"msCentral INT, " +
+		       	"future1 TEXT )";
+		dbcmd.ExecuteNonQuery();
+	}
+	
+	public static void SignalCurveInsert(bool dbconOpened, int signalID, int curveID, int msCentral)
+	{
+		if(! dbconOpened)
+			dbcon.Open();
+
+		dbcmd.CommandText = "INSERT INTO " + Constants.EncoderSignalCurveTable +  
+			" (uniqueID, signalID, curveID, msCentral, future1) " + 
+			"VALUES (NULL, " + signalID + ", " + curveID + ", " + msCentral + ", '')";
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		
+		if(! dbconOpened)
+			dbcon.Close();
+	}
+	
+
+	//signalID == -1 (any signal)
+	//curveID == -1 (any curve)
+	//if msStart and msEnd != -1 (means find a curve with msCentral contained between both values)
+	public static ArrayList SelectSignalCurve (bool dbconOpened, int signalID, int curveID, double msStart, double msEnd)
+	{
+		if(! dbconOpened)
+			dbcon.Open();
+
+		string whereStr = "";
+		if(signalID != -1 || curveID != -1 || msStart != -1)
+			whereStr = " WHERE ";
+		
+		string signalIDstr = "";
+		if(signalID != -1)
+			signalIDstr = " signalID == " + signalID;
+		
+		string curveIDstr = "";
+		if(curveID != -1) {
+			curveIDstr = " curveID == " + curveID;
+			if(signalID != -1)
+				curveIDstr = " AND" + curveIDstr;
+		}
+
+		string msCentralstr = "";
+		if(msStart != -1) {
+			msCentralstr = " msCentral >= " + Util.ConvertToPoint(msStart) + " AND msCentral <= " + Util.ConvertToPoint(msEnd);
+			if(signalID != -1 || curveID != -1)
+				msCentralstr = " AND" + msCentralstr;
+		}
+
+		dbcmd.CommandText = 
+			"SELECT uniqueID, signalID, curveID, msCentral " +
+			" FROM " + Constants.EncoderSignalCurveTable + 
+			whereStr + signalIDstr + curveIDstr + msCentralstr;
+		
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+
+		ArrayList array = new ArrayList();
+		while(reader.Read()) {
+			EncoderSignalCurve esc = new EncoderSignalCurve(
+					Convert.ToInt32(reader[0].ToString()),
+					Convert.ToInt32(reader[1].ToString()),
+					Convert.ToInt32(reader[2].ToString()),
+					Convert.ToInt32(reader[3].ToString()));
+			
+			array.Add(esc);
+		}
+		reader.Close();
+		if(! dbconOpened)
+			dbcon.Close();
+
+		return array;
+	}
+
+	public static void DeleteSignalCurveWithCurveID(bool dbconOpened, int curveID)
+	{
+		if( ! dbconOpened)
+			dbcon.Open();
+
+		dbcmd.CommandText = "Delete FROM " + Constants.EncoderSignalCurveTable +
+			" WHERE curveID == " + curveID.ToString();
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		
+		if( ! dbconOpened)
+			dbcon.Close();
+	}
+
 	
 
 	/*
@@ -586,6 +701,56 @@ class SqliteEncoder : Sqlite
 
 		return array;
 	}
-	
+
+
+	/* 
+	 * database conversions	
+	 */
+
+	//convert from DB 1.05 to 1.06
+	//1.06 have curves connected to signals
+	//as curves detection on every signal can change depending on smoothing, minimal_height, ...
+	//1.06 needs to know where the curve is located in the signal
+	//starting ms is not reliable because changes with smoothing
+	//use central millisecond.
+	//
+	//this method will find where the central millisecond of a curve is located in a signal
+	//and this will be stored in 1.06 in new EncoderSignalCurve table
+	//signalID,curveID,contraction(c,ecS,ceS),msCentral
+	//encoder table will continue with signals and curves because we don't want to break things now
+	//
+	//as explained, following method is only used in conversions from 1.05 to 1.06
+	//newly saved curves in 1.06 will write msCentral in EncoderSignalCurve table without needing this method
+	public static int FindCurveInSignal(string signalFile, string curveFile) 
+	{
+		int [] signalInts = Util.ReadFileAsInts(signalFile);
+		/*	
+		Log.WriteLine("found INTS");
+		for(int i=0; i < signalInts.Length; i ++)
+			Log.Write(signalInts[i] + " ");
+		*/	
+
+		int [] curveInts = Util.ReadFileAsInts(curveFile);
+		/*
+		Log.WriteLine("found INTS");
+		for(int i=0; i < curveInts.Length; i ++)
+			Log.Write(curveInts[i] + " ");
+		*/
+
+		int c;
+		for(int s=0; s < signalInts.Length; s ++) {
+			for(c=0; c < curveInts.Length && (s + c < signalInts.Length); c ++)
+				if(signalInts[s + c] != curveInts[c])
+					break;
+			
+			if(c == curveInts.Length) {
+				//Log.WriteLine("Start at: " + s);
+				//Log.WriteLine("Middle at: " + s + Convert.ToInt32(c / 2));
+				return s + Convert.ToInt32(c / 2);
+			}
+		}
+
+		return -1;
+	}
 
 }
