@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -933,7 +933,7 @@ Log.WriteLine(intervalSpeeds);
 		return myArray;
 	}
 	
-	//is the same as IeIub except the moreSelect lines
+	//is the same as IE, Arms Use Index except the moreSelect lines
 	public static ArrayList JumpSimpleSubtraction (string sessionString, bool multisession, string ini, string end, string jump1, string jump2, bool showSex)
 	{
 		string tp = Constants.PersonTable;
@@ -1135,7 +1135,7 @@ Log.WriteLine(intervalSpeeds);
 		}
 		else if (indexType == Constants.PotencyShettyFormulaShort) {
 			moreSelect = 
-				ini + "((1925.72 * 100 * " + jumpHeightInM + ") + (14.74 * (" + totalWeight + ")) - 66.3)" + end + ", 1, "; //the "1" is for selecting something for compatibility with potencyLewis that needs to select two things
+				ini + "((1925.72 * " + jumpHeightInM + ") + (14.74 * (" + totalWeight + ")) - 666.3)" + end + ", 1, "; //the "1" is for selecting something for compatibility with potencyLewis that needs to select two things
 		}
 		else if (indexType == Constants.PotencyCanavanFormulaShort) {
 			moreSelect = 
@@ -1358,259 +1358,4 @@ Log.WriteLine(intervalSpeeds);
 	}
 	
 	
-	/*
-	public static ArrayList GlobalNormal (string sessionString, string operation, bool sexSeparated, 
-			int personID, bool heightPreferred)
-	{
-		dbcon.Open();
-		
-		string personString = "";
-		if(personID != -1) { 
-			personString = " AND jump.personID == " + personID;
-		}
-		
-		if (sexSeparated) {
-			dbcmd.CommandText = "SELECT type, sessionID, " + operation + "(tv), sex" + 
-				" FROM jump, person " +
-				sessionString + 
-				" AND jump.personID == person.uniqueID" + personString +
-				" GROUP BY jump.type, sessionID, person.sex " +
-				" ORDER BY jump.type, person.sex DESC, sessionID" ; 
-		} else {
-		
-			dbcmd.CommandText = "SELECT type, sessionID, " + operation + "(tv) " +
-				" FROM jump " +
-				sessionString + personString +
-				" GROUP BY type, sessionID " +
-				" ORDER BY type, sessionID " ; 
-		}
-
-		Log.WriteLine(dbcmd.CommandText.ToString());
-		dbcmd.ExecuteNonQuery();
-		
-		SqliteDataReader reader;
-		reader = dbcmd.ExecuteReader();
-
-		//returns always two columns
-		ArrayList myArray = new ArrayList(2);
-		while(reader.Read()) {
-			if (reader[0].ToString() != "DJ") {
-
-				string heightString = Util.ChangeDecimalSeparator(reader[2].ToString());
-				if(heightPreferred) {
-					heightString = Util.GetHeightInCentimeters(Util.ChangeDecimalSeparator(reader[2].ToString()));
-				}
-				
-				if (sexSeparated) {
-					myArray.Add (reader[0].ToString() + "." + reader[3].ToString() + ":" +
-							reader[1].ToString() + ":" + heightString
-							);
-				} else {
-					myArray.Add (reader[0].ToString() + ":" + reader[1].ToString() 
-							+ ":" + heightString 
-							);
-				}
-			}
-		}
-		
-		reader.Close();
-		dbcon.Close();
-		
-		return myArray;
-	}
-
-	//djindex, qindex, rjIndex, rjpotency(bosco)
-	public static ArrayList GlobalOthers (string statName, string statFormulae, string jumpTable, string sessionString, string operation, bool sexSeparated, int personID)
-	{
-
-		//select all possible jumpTypes and put in jumpTypeString for SQL
-		string jumpTypeString= " AND (";
-		string [] myJumpTypes;
-		if(jumpTable == "jump") {
-			myJumpTypes = SqliteJumpType.SelectJumpTypes("", "TC", true);
-		} else {
-			myJumpTypes = SqliteJumpType.SelectJumpRjTypes("", true);
-		}
-		for(int i=0; i < myJumpTypes.Length ; i++) {
-			if (i>0) {
-				jumpTypeString += " OR ";
-			}
-			jumpTypeString += " type == '" + myJumpTypes[i] + "'";
-		}
-		jumpTypeString += " ) ";
-	
-		
-		dbcon.Open();
-
-		
-		string personString = "";
-		if(personID != -1) { 
-			personString = " AND personID == " + personID;
-		}
-		
-		if (sexSeparated) {
-			//select the MAX or AVG index grouped by sex
-			//returns 0-2 rows
-			dbcmd.CommandText = "SELECT sessionID, type, " + operation + statFormulae + ", sex " + 
-				" FROM " + jumpTable + ", person " +
-				sessionString +	
-				" AND personID == person.uniqueID" +
-				jumpTypeString +
-				personString +
-				" GROUP BY sessionID, type, person.sex " +
-				" ORDER BY person.sex DESC, type, sessionID" ; 
-		} else {
-			//select the MAX or AVG index. 
-			//returns 0-1 rows
-			dbcmd.CommandText = "SELECT sessionID, type, " + operation + statFormulae +
-				" FROM " + jumpTable + " " +
-				sessionString +	
-				jumpTypeString +
-				personString +
-				//the following solves a problem
-				//of sqlite, that returns an 
-				//"empty line" when there are no
-				//values to return in a index
-				//calculation.
-				//With the group by, 
-				//if there are no values, 
-				//it does not return any line
-				" GROUP by sessionID, type " +
-				" ORDER by type, sessionID";
-		}
-
-		Log.WriteLine(dbcmd.CommandText.ToString());
-		dbcmd.ExecuteNonQuery();
-		
-		SqliteDataReader reader;
-		reader = dbcmd.ExecuteReader();
-
-		ArrayList myArray = new ArrayList(2);
-		
-		//returns always two columns
-		while(reader.Read()) {
-			if (sexSeparated) {
-				myArray.Add (statName + " (" + reader[1].ToString()  + ")" + 	//stat name(jumptype)
-						"." + reader[3].ToString() + ":" + 		//sex
-						reader[0].ToString() + ":" + Util.ChangeDecimalSeparator(reader[2].ToString()) //session, value
-						);
-			} else {
-				myArray.Add (statName + " (" + reader[1].ToString()  + ") " + ":" + 	//stat name (jumptype)
-						reader[0].ToString() + ":" + Util.ChangeDecimalSeparator(reader[2].ToString())	//session, value
-						);
-			}
-		}
-		
-		reader.Close();
-		dbcon.Close();
-		
-		return myArray;
-	}
-
-	//IE, IUB, FV
-	public static ArrayList GlobalIndexes (string statName, string jump1, string jump2, string sessionString, string operation, bool sexSeparated, int personID)
-	{
-		dbcon.Open();
-
-		string moreSelect = "";
-		string weightString = ""; //used by FV index
-		int sexColumn = 0;
-		
-		if(statName == "FV") {
-			string heightJump1 = " 100*4.9* (j1.tv/2.0) * (j1.tv/2.0) ";	//jump1 tv converted to height
-			string heightJump2 = " 100*4.9* (j2.tv/2.0) * (j2.tv/2.0) ";	//jump2 tv converted to height
-			if(operation == "MAX") {
-				//search MAX of two jumps, not max index!!
-				moreSelect = " ( MAX(" + heightJump1 + ") )*100/(1.0*MAX(" + heightJump2 + ")) AS myIndex, " +
-					"MAX(" + heightJump1 + "), MAX(" + heightJump2 + ") ";
-			} else if(operation == "AVG") {
-				moreSelect = " ( AVG(" + heightJump1 + ") )*100/(1.0*AVG(" + heightJump2 + ")) AS myIndex, " +
-					"AVG(" + heightJump1 + "), AVG(" + heightJump2 + ")";
-			}
-			//weightString = " AND (j1.weight == \"100%\" OR j1.weight == person.weight||'" + "Kg' ) ";
-			weightString = 
-				// now jump weight is not stores as % or kg and with the '%' or 'kg' after. Is always a %
-				//" AND (j1.weight == \"100%\" OR j1.weight == personSessionWeight.weight||'" + "Kg' ) " +
-				
-				" AND j1.weight == \"100\" ";
-			sexColumn = 4;
-		} else {	//IE, IUB
-			if(operation == "MAX") {
-				//search MAX of two jumps, not max index!!
-				moreSelect = "( ( MAX(j1.tv) - MAX(j2.tv) )*100/(MAX(j2.tv)*1.0) ) AS myIndex ";
-			} else if(operation == "AVG") {
-				moreSelect = "( ( AVG(j1.tv) - AVG(j2.tv) )*100/(AVG(j2.tv)*1.0) ) AS myIndex ";
-			}
-			sexColumn = 2;
-		}
-		
-		string personString = "";
-		if(personID != -1) { 
-			personString = " AND j1.personID == " + personID + " AND j2.personID == " + personID + " ";
-		}
-		
-		if (sexSeparated) {
-			//select the MAX or AVG index grouped by sex
-			//returns 0-2 rows
-			dbcmd.CommandText = "SELECT j1.sessionID, " + moreSelect + ", person.sex " +
-				" FROM jump AS j1, jump AS j2, person, personSessionWeight " +
-				sessionString +	
-				weightString + 		//used by FV
-				" AND j1.personID == person.uniqueID" +
-				" AND j2.personID == person.uniqueID" +
-				" AND j1.type == '" + jump1 + "'" + 
-				" AND j2.type == '" + jump2 + "'" + 
-				personString +
-				" GROUP BY j1.sessionID, person.sex " +
-				" ORDER BY person.sex DESC, j1.sessionID" ; 
-		} else {
-			//select the MAX or AVG index. 
-			//returns 0-1 rows
-			dbcmd.CommandText = "SELECT j1.sessionID, " + moreSelect +
-				" FROM jump AS j1, jump AS j2, person, personSessionWeight " +
-				sessionString +	
-				weightString + 		//used by FV
-				" AND j1.personID == person.uniqueID" +
-				" AND j2.personID == person.uniqueID" +
-				" AND j1.type == '" + jump1 + "'" + 
-				" AND j2.type == '" + jump2 + "'" + 
-				personString +
-				//the following solves a problem
-				//of sqlite, that returns an 
-				//"empty line" when there are no
-				//values to return in a index
-				//calculation.
-				//With the group by, 
-				//if there are no values, 
-				//it does not return any line
-				" GROUP by j1.sessionID" +
-				" ORDER by j1.sessionID";
-		}
-
-		Log.WriteLine(dbcmd.CommandText.ToString());
-		dbcmd.ExecuteNonQuery();
-		
-		SqliteDataReader reader;
-		reader = dbcmd.ExecuteReader();
-
-		ArrayList myArray = new ArrayList(2);
-		
-		//returns always two columns
-		while(reader.Read()) {
-			if (sexSeparated) {
-				myArray.Add (statName +"." + reader[sexColumn].ToString() + ":" + reader[0].ToString() 
-							+ ":" + Util.ChangeDecimalSeparator(reader[1].ToString()) );
-			} else {
-				myArray.Add (statName + ":" + reader[0].ToString() 
-							+ ":" + Util.ChangeDecimalSeparator(reader[1].ToString())	);
-			}
-		}
-		
-		reader.Close();
-		dbcon.Close();
-		
-		return myArray;
-	}
-	*/
-
 }
