@@ -734,6 +734,10 @@ public class Util
 
 	/********** end of database paths ************/
 	
+	public static string GetLogsDir() {
+		return Path.Combine(Path.GetTempPath(), "Chronojump-logs");
+	}
+
 	/********** start of multimedia paths ************/
 
 	public static string GetMultimediaDir() {
